import { useState, useEffect } from 'react'
import axios from 'axios'

const Filter = ({filter, setFilter}) => (
  <div>
    find countries <input value={filter} onChange={e => setFilter(e.target.value) } />
  </div>
)

const ManyCountries = ({countries, setFilter}) => (
  <div>
    <ul>
      {countries.map(country =>
        <li key={country.name.official}>
          {country.name.common}
          <input type="button" value="show" onClick={() => setFilter(country.name.common)} />
        </li>)
      }
    </ul>
  </div>
)

const SingleCountry = ({country}) => (
  <div>
    <h1>{country.name.common}</h1>
    <p>capital {country.capital[0]}<br/>
    area {country.area}</p>

    <h3>languages:</h3>
    <ul>
      {Object.entries(country.languages).map(language => <li key={language[0]}>{language[1]}</li>)}
    </ul>

    <img alt={`${country.name.common} flag`} src={country.flags.png} />
  </div>
)

const Countries = ({countries, filter, setFilter}) => {
  if(!filter) return <ManyCountries countries={countries} setFilter={setFilter} />

  const countriesToDisplay =
    countries.filter(country => country.name.common.toLowerCase().includes(filter))

  if(countriesToDisplay.length > 10)
    return <div>Too many matches, specify another filter</div>

  else if(countriesToDisplay.length === 1)
    return <SingleCountry country={countriesToDisplay[0]} />

  else return <ManyCountries countries={countriesToDisplay} setFilter={setFilter} />
}

const App = () => {
  const [filter, setFilter] = useState('')
  const [countries, setCountries] = useState([])

  useEffect(() => {
    axios
      .get('https://restcountries.com/v3.1/all')
      .then(response => setCountries(response.data))
  }, [])

  return (
    <div>
      <Filter filter={filter} setFilter={setFilter} />
      <Countries countries={countries} filter={filter.toLowerCase()} setFilter={setFilter} />
    </div>
  )
}

export default App;
